==> pw-iso20022-SRU2020-9.1.5-sources.jar: com/prowidesoftware/swift/model/mx/dic/AlternateFinancialInstrumentIdentification1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * A proprietary or domestic identification scheme that uniquely identifies a financial instrument.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AlternateFinancialInstrumentIdentification1", propOrder = {
    "dmstIdSrc",
    "prtryIdSrc",
    "id"
})
public class AlternateFinancialInstrumentIdentification1 {

    @XmlElement(name = "DmstIdSrc")
    protected String dmstIdSrc;
    @XmlElement(name = "PrtryIdSrc")
    protected String prtryIdSrc;
    @XmlElement(name = "Id", required = true)
    protected String id;

    /**
     * Gets the value of the dmstIdSrc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDmstIdSrc() {
        return dmstIdSrc;
    }

    /**
     * Sets the value of the dmstIdSrc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public AlternateFinancialInstrumentIdentification1 setDmstIdSrc(String value) {
        this.dmstIdSrc = value;
        return this;
    }

    /**
     * Gets the value of the prtryIdSrc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrtryIdSrc() {
        return prtryIdSrc;
    }

    /**
     * Sets the value of the prtryIdSrc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public AlternateFinancialInstrumentIdentification1 setPrtryIdSrc(String value) {
        this.prtryIdSrc = value;
        return this;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public AlternateFinancialInstrumentIdentification1 setId(String value) {
        this.id = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.9-sources.jar: com/prowidesoftware/swift/model/mx/dic/AlternateFinancialInstrumentIdentification1.java <==

package com.prowidesoftware.swift.model.mx.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * A proprietary or domestic identification scheme that uniquely identifies a financial instrument.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AlternateFinancialInstrumentIdentification1", propOrder = {
    "dmstIdSrc",
    "prtryIdSrc",
    "id"
})
public class AlternateFinancialInstrumentIdentification1 {

    @XmlElement(name = "DmstIdSrc")
    protected String dmstIdSrc;
    @XmlElement(name = "PrtryIdSrc")
    protected String prtryIdSrc;
    @XmlElement(name = "Id", required = true)
    protected String id;

    /**
     * Gets the value of the dmstIdSrc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDmstIdSrc() {
        return dmstIdSrc;
    }

    /**
     * Sets the value of the dmstIdSrc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public AlternateFinancialInstrumentIdentification1 setDmstIdSrc(String value) {
        this.dmstIdSrc = value;
        return this;
    }

    /**
     * Gets the value of the prtryIdSrc property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPrtryIdSrc() {
        return prtryIdSrc;
    }

    /**
     * Sets the value of the prtryIdSrc property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public AlternateFinancialInstrumentIdentification1 setPrtryIdSrc(String value) {
        this.prtryIdSrc = value;
        return this;
    }

    /**
     * Gets the value of the id property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getId() {
        return id;
    }

    /**
     * Sets the value of the id property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public AlternateFinancialInstrumentIdentification1 setId(String value) {
        this.id = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
